<?php
/**
 * The featured layouts
 *
 * @package Publisher
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class Publisher_Featured_Layouts extends Publisher_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = publisher_get_settings( 'featured_categories' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = [
				'layout'         => 'default',
				'posts_layout'   => 'layout-default',
				'excerpt_length' => 15,
				'unique_id'      => 'nothing',
				'is_latest'      => true,
			];

			get_template_part( 'template-parts/posts', 'default' );
			return;
		}

		$has_latest_posts = $this->has_latest_posts_section( $this->sections );

		foreach ( $this->sections as $section ) :

			$posts_layout = $section['blog_layout'];

			$layout = $posts_layout;
			if ( 'layout-default' === $posts_layout ) {
				$layout = 'default';
			}

			$category = $section['mts_featured_category'];

			if ( is_paged() ) {

				if ( $has_latest_posts && 'latest' !== $category ) {
					continue;
				}

				if ( 'layout-html' === $layout ) {
					continue;
				}

				$this->current = [
					'layout'         => $layout,
					'posts_layout'   => $posts_layout,
					'category'       => $category,
					'excerpt_length' => $section['mts_featured_category_excerpt'],
					'unique_id'      => $section['unique_id'],
					'is_latest'      => false,
				];
				get_template_part( 'template-parts/posts', $layout );
				return;
			}

			$section = wp_parse_args( array_filter( $section ), [
				'blog_layout'                      => '',
				'mts_featured_category_postsnum'   => 3,
				'mts_featured_category_excerpt'    => 15,
				'mts_featured_category_background' => '',
				'mts_featured_category_margin'     => '',
				'mts_featured_category_padding'    => '',
				'unique_id'                        => '',
			] );

			if ( 'latest' !== $category ) {
				$this->category_posts( $category, $section['mts_featured_category_postsnum'] );
			}

			$this->current = [
				'layout'         => $layout,
				'category'       => $category,
				'unique_id'      => $section['unique_id'],
				'is_latest'      => 'latest' !== $category,
				'posts_layout'   => $posts_layout,
				'posts_count'    => $section['mts_featured_category_postsnum'],
				'excerpt_length' => $section['mts_featured_category_excerpt'],
			];
			if ( have_posts() ) {
				get_template_part( 'template-parts/posts', $layout );
			}

		endforeach;
	}

	/**
	 * Check if array of sections contains a Latest Posts section.
	 *
	 * @param array $sections Sections.
	 * @return boolean
	 */
	public function has_latest_posts_section( $sections ) {
		foreach ( $sections as $section ) {
			if ( 'latest' === $section['mts_featured_category'] ) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = [];
		$classes[] = 'layout-' . $this->current['unique_id'];
		$classes[] = $this->current['layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes );
	}

	/**
	 * Set category in main query
	 *
	 * @param  int $category    Category ID.
	 * @param  int $posts_count Number of posts.
	 */
	public function category_posts( $category, $posts_count ) {
		global $wp_query;

		$wp_query = new WP_Query( 'ignore_sticky_posts=1&category_name=' . $category . '&posts_per_page=' . $posts_count );
	}

	/**
	 * Get section title.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_section_title( $category = false ) {
		if ( publisher_get_settings( 'featured_category_title_' . $this->current['unique_id'] ) ) :
			$category = ! $category ? $this->current['category'] : $category;
			?>
		<div class="title-container title-id-<?php echo $this->current['unique_id']; ?>">
			<?php
			if ( ! $this->current['is_latest'] && 'latest' === $category ) {
				echo '<h3 class="featured-category-title">';
				esc_html_e( 'Latest', 'publisher' );
				echo '</h3></div>';
				return;
			}
			$category_name = publisher_get_cat_name( $category );
			$category_id   = get_cat_ID( $category_name );
			?>
			<h3 class="featured-category-title"><a href="<?php echo esc_url( get_category_link( $category_id ) ); ?>" title="<?php echo esc_attr( $category_name ); ?>"><?php echo esc_html( $category_name ); ?></a></h3>
		</div>
			<?php
		endif;
	}

	/**
	 * Get Default layout post meta info
	 *
	 * @param  boolean $top, $bottom Display meta.
	 */
	public function get_post_metainfo( $top = false, $bottom = false ) {
		$featured_meta_info = publisher_get_settings( 'mts_home_headline_meta_info_' . $this->current['unique_id'] );
		// Meta Items.

		$category = isset( $featured_meta_info['category'] ) ? $featured_meta_info['category'] : 0;
		$comment  = isset( $featured_meta_info['comment'] ) ? $featured_meta_info['comment'] : 0;
		$auth_img = isset( $featured_meta_info['auth-img'] ) ? $featured_meta_info['auth-img'] : 0;
		$author   = isset( $featured_meta_info['author'] ) ? $featured_meta_info['author'] : 0;
		$time     = isset( $featured_meta_info['time'] ) ? $featured_meta_info['time'] : 0;
		$likes    = isset( $featured_meta_info['likes'] ) ? $featured_meta_info['likes'] : 0;

		if ( 'top' === $top ) {
			if ( $category || $comment ) :
				?>
				<div class="post-info-upper">
					<?php
					if ( isset( $category ) ) :
						if ( publisher_get_settings( 'mts_home_category_type_' . $this->current['unique_id'] ) ) {
							?>
							<div class="thecategory"><?php echo publisher_get_the_category( '' ); ?></div>
							<?php
						} else {
							$category = get_the_category();
							if ( ! empty( $category ) ) {
								?>
								<div class="thecategory"><?php echo '<a href="' . get_category_link( $category[0]->term_id ) . '" title="' . esc_attr( sprintf( __( 'View all posts in %s', 'publisher' ), $category[0]->name ) ) . '">' . $category[0]->cat_name . '</a>'; ?></div>
								<?php
							}
						}
					endif;
					if ( $comment ) :
						printf( '<span class="thecomment"><a href="%1$s" itemprop="interactionCount">%2$s</a></span>', esc_url( get_comments_link() ), get_comments_number_text() );
					endif;
					?>
				</div>
				<?php
			endif;
		}

		if ( 'bottom' === $bottom ) {
			if ( $auth_img || $author || $time || $likes ) :
				?>
				<div class="post-info-bottom">
					<?php
					if ( $auth_img || $author || $time ) :
						echo '<div class="post-info-left">';
						if ( $auth_img ) :
							?>
							<div class="theauthorimage"><?php echo get_avatar( get_the_author_meta( 'email' ), 40 ); ?></div>
							<?php
						endif;
						echo '<div class="theauthortime">';
						if ( $author ) :
							printf( '<div class="theauthor"><span>%s</span></div>', get_the_author_posts_link() );
						endif;
						if ( $time ) :
							printf( '<div class="thetime date updated"><span>%s</span></div>', get_the_time( get_option( 'date_format' ) ) );
						endif;
						echo '</div>';
						echo '</div>';
					endif;
					if ( $likes ) :
						echo '<div class="thelikebutton">';
						echo get_simple_likes_button( get_the_ID() );
						echo '</div>';
					endif;
					?>
				</div>
				<?php
			endif;
		}
	}

	/**
	 * Get post title
	 */
	public function get_post_title( $meta = true ) {
		?>
		<header>
			<?php
			if ( $meta ) {
				publisher_the_post_meta( 'home', $this->current['unique_id'] );
			}
			?>
			<h2 class="title front-view-title">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
			</h2>
		</header>
		<?php
	}

	/**
	 * Get post thumbnail according to layout
	 *
	 * @param  boolean Display review.
	 */
	public function get_post_thumbnail() {

		$default_thumb = 'publisher-featured';
		$thumbs        = [
			'layout-default' => 'publisher-featured',
			'layout-1'       => 'publisher-slider',
			'layout-2'       => 'publisher-layout-2',
		];
		if ( wp_is_mobile() ) {
			$default_thumb = 'publisher-featured';
			$mthumb        = [
				'layout-1' => 'publisher-related',
			];
			// replaced array.
			$thumbs = array_replace( $thumbs, $mthumb );
		}
		// post layout size.
		$size = isset( $thumbs[ $this->current['posts_layout'] ] ) ? $thumbs[ $this->current['posts_layout'] ] : $default_thumb;
		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo $size; ?>">
			<div class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $size, [ 'title' => '' ] );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $size . '.png" alt="' . __( 'No Preview', 'publisher' ) . '"  class="wp-post-image" />';
				}
				?>
			</div>
			<?php
			if ( function_exists( 'wp_review_show_total' ) ) {
				wp_review_show_total( true, 'latestPost-review-wrapper' );
			}
			?>
		</a>
		<?php
	}

	/**
	 * Get post content
	 */
	public function get_post_content() {
		?>

		<div class="front-view-content">
			<?php
			if ( empty( publisher_excerpt() ) ) {
				echo publisher_truncate( get_the_content(), $this->current['excerpt_length'], 'words' );
			} else {
				echo publisher_excerpt( $this->current['excerpt_length'] );
			}
			?>
		</div>

		<?php
	}

	/**
	 * Get sidebar
	 *
	 */
	public function get_sidebar() {

		$cat_name = __( 'Latest ', 'publisher' );

		if ( 'latest' !== $this->current['category'] ) {
			$cat_name = ucwords( publisher_get_cat_name( $this->current['category'] ) );
		}
		if ( 'default' == $this->current['layout'] ) {
			$this->current['layout'] = 'layout-default';
		}
		?>
		<aside id="sidebar" class="sidebar c-4-12 post-<?php echo $this->current['layout']; ?>" role="complementary" itemscope itemtype="http://schema.org/WPSideBar">
			<?php
			dynamic_sidebar( sanitize_title( strtolower( 'post-' . $this->current['layout'] . $cat_name ) ) );
			?>
		</aside>
		<?php
	}

	/**
	 * Get post pagination
	 */
	public function get_post_pagination() {
		if ( ! $this->current['is_latest'] ) {
			publisher_pagination( publisher_get_settings( 'mts_pagenavigation_type' ) );
		}
		wp_reset_query();
	}
}
