<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Publisher
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function publisher_implode( $elements = [] ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function publisher_map_selector( $elements, $selector ) {
	$array = [];

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function publisher_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function publisher_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function publisher_dynamic_css_array() {

	global $wp_version;

	$css       = [];
	$c_page_id = publisher()->get_page_id();

	// Site Background.
	$css['global']['html body, #sidebar .widget h3 span'] = Publisher_Sanitize::background( publisher_get_settings( 'theme_background' ) );

	// Header Background.

	// Logo Font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'publisher_logo' ) ) );
	// Primary Navigation font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'content_font' ) ) );
	// Pagination.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'pagination_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'loadmore_font' ) ) );
	// Single post title font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'pages_title_font' ) ) );
	// Single Page titles font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_subscribe_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_subscribe_text_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_subscribe_input_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_subscribe_submit_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'authorbox_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'authorbox_author_name_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'authorbox_registered_date_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'authorbox_text_font' ) ) );
	// Sidebar widget title font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_links_widgets' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_post_title' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_large_post_title' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_postinfo_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_post_number' ) ) );
	// Footer widget title font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'top_footer_title_font' ) ) );
	// Footer widget font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'top_footer_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_links_widgets' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'top_footer_post_title' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_large_post_title' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'top_footer_meta_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'top_footer_post_number' ) ) );
	// Copyrights section font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'fields_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'buttons_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'blockquote_font' ) ) );
	// H1 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'h6_headline' ) ) );
	// Footer background.
	$css['global']['#site-footer'] = Publisher_Sanitize::background( publisher_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Publisher_Sanitize::background( publisher_get_settings( 'mts_copyrights_background' ) );
	// Sidebar Subscribe Widget.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'subscribe_widget_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'sidebar_fields_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'subscribe_widget_text_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'subscribe_widget_submit_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'subscribe_widget_small_text_font' ) ) );
	// Footer Subscribe Widget.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_subscribe_widget_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_fields_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_subscribe_widget_text_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_subscribe_widget_submit_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'footer_subscribe_widget_small_text_font' ) ) );
	publisher_dynamic_css_skin( $css );
	publisher_sidebar_position( $css );
	publisher_header( $css );
	publisher_sidebar_styling( $css );
	publisher_post_layouts( $css );
	publisher_post_pagination( $css );
	publisher_footer( $css );
	publisher_copyrights( $css );
	publisher_single( $css );
	publisher_featured_area_post( $css );
	publisher_single_social_buttons( $css );
	publisher_archive_post( $css );
	publisher_misc_css( $css );

	return apply_filters( 'publisher_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme = Publisher_Sanitize::color( publisher_get_settings( 'primary_color_scheme' ) );

	// Text Color.
	$elements = [
		'a',
		'body a:hover',
		'.sidebar .widget li a:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'.related-readmore a',
		'.widget .sbutton:hover',
		'.shareit-circular.standard .share-text',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
		'.f-widget .aboutme-widget .aboutme-social a:hover',
		'.aboutme-widget .aboutme-social a:hover',
		'#copyright-note a:hover',
		'.total-posts-number',
		'.tags a:hover',
		'.tagcloud a:hover',
		'.woocommerce .woocommerce-breadcrumb a:hover',
		'.widget .wpt_widget_content #tags-featured-tab-content ul li a:hover',
		'.theauthortime .theauthor',
		'.thelikebutton a',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.woocommerce nav.woocommerce-pagination ul li span',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
	];
	$css['global'][ publisher_implode( $elements ) ]['color'] = $primary_color_scheme;

	// Primary Text Color Important.
	$elements = [
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.widget.widget_categories li a:hover',
		'.widget.widget_archive li a:hover',
		'.widget.widget_pages li a:hover',
		'.widget.widget_meta li a:hover',
		'.widget.widget_recent_comments li a:hover',
		'.widget.widget_recent_entries li a:hover',
		'.widget.widget_rss li a:hover',
		'.widget.widget_nav_menu li a:hover',
		'.post-title a:hover',
		'.entry-title a:hover',
		'.shareit-circular.standard .fa:hover',
		'.latestPost .title a:hover',
		'.post-info a:hover',
		'.tagcloud a:hover',
		'.sidebar .widget li.horizontal-small .post-title a:hover',
		'.widget .wpt_widget_content #tags-featured-tab-content ul li a:hover',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.widget .wpt-pagination a:hover',
		'.widget .wp-review-tab-pagination a:hover',
		'.widget .wpt_widget_content .tab_title.selected a',
		'.widget .wp_review_tab_widget_content .tab_title.selected a',
	];
	$css['global'][ publisher_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Primary Background Color.
	$elements = [
		'.prev-next .prev a',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.instagram-button a',
		'.woocommerce a.button, .woocommerce button.button',
		'.woocommerce input.button, .woocommerce #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce-page a.button, .woocommerce-page button.button',
		'.woocommerce-page input.button',
		'.woocommerce-page #respond input#submit',
		'.woocommerce-page #content input.button',
		'.woocommerce-page .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce div.product form.cart .button',
		'.woocommerce-page div.product form.cart .button',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.woocommerce a.checkout-button.button',
		'.woocommerce #payment #place_order',
		'.woocommerce-page #payment #place_order',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.button',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		// secondary.
		'.owl-prev:hover, .owl-next:hover',
		'#wpmm-megamenu .review-total-only',
		'.button:hover',
		'.prev-next .prev a:hover',
		'.prev-next .next a:hover',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt:hover',
		'.woocommerce button.button.alt:hover',
		'.woocommerce input.button.alt:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.instagram-button a:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.woocommerce-page div.product form.cart .button:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce #payment #place_order:hover',
		'.woocommerce-page #payment #place_order:hover',
	];
	$css['global'][ publisher_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $primary_color_scheme;

	// Background Color Important.
	$elements = [
		'.shareit-circular.circular-standard .social-icon:hover',
	];
	$css['global'][ publisher_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = [
		'.page-numbers.current',
		'.pagination a:hover',
		'.widget #wp-subscribe input.email-field:focus',
		'.widget #wp-subscribe input.name-field:focus',
	];
	$css['global'][ publisher_implode( $elements ) ]['border-color'] = $primary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = publisher_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== publisher_get_settings( 'mts_social_button_position' ) && 'floating' === publisher_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = [
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			];

			$css['global'][ publisher_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ publisher_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ publisher_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ publisher_implode( $shareit_class ) ]['margin-right'] = publisher_px2rem( '100px' );
		}
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_header( &$css ) {
	$header_class = [
		'#header',
		'#site-header .header-search .searchbox',
		'#site-header .header-search .searchbox.searchbox-open .searchbox-icon',
	];
	// background.
	$css['global'][ publisher_implode( $header_class ) ] = Publisher_Sanitize::background( publisher_get_settings( 'header_background' ) );
	publisher_merge_value( $css['global']['#header'], Publisher_Sanitize::margin( publisher_get_settings( 'header_margin' ) ) );
	publisher_merge_value( $css['global']['#header'], Publisher_Sanitize::padding( publisher_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Publisher_Sanitize::border( publisher_get_settings( 'header_border' ) );
	$css['global']['#header'][ $header_border['direction'] ] = $header_border ['value'];

	$css['global']['#primary-navigation .navigation ul ul a']['color']            = Publisher_Sanitize::color( publisher_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul']['background']         = Publisher_Sanitize::color( publisher_get_settings( 'main_navigation_dropdown_background' ) );
	$css['global']['#primary-navigation .navigation ul ul']['border-radius']      = Publisher_Sanitize::size( publisher_get_settings( 'main_navigation_dropdown_border_radius' ) . 'px' );
	$css['global']['#primary-navigation .navigation ul li:hover > a']['color']    = Publisher_Sanitize::color( publisher_get_settings( 'main_navigation_hover_color' ) );
	$css['global']['#primary-navigation .navigation ul ul li:hover > a']['color'] = Publisher_Sanitize::color( publisher_get_settings( 'main_navigation_dropdown_hover_color' ) );
	// Nav Padding.
	publisher_merge_value( $css['global']['#primary-navigation'], Publisher_Sanitize::padding( publisher_get_settings( 'header_nav_padding' ) ) );
	// Social icons.
	$header_icons = publisher_get_settings( 'header_social_icons' );
	if ( ! empty( $header_icons ) && is_array( $header_icons ) ) :
		foreach ( $header_icons as $header_icon ) :
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color']            = Publisher_Sanitize::color( $header_icon['header_icon_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Publisher_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color']                       = Publisher_Sanitize::color( $header_icon['header_icon_color'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color']            = Publisher_Sanitize::color( $header_icon['header_icon_hover_color'] );
			publisher_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Publisher_Sanitize::margin( $header_icon['header_icon_margin'] ) );
			publisher_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Publisher_Sanitize::padding( $header_icon['header_icon_padding'] ) );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Publisher_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );
		endforeach;
	endif;

	// Header Ad.
	publisher_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Publisher_Sanitize::margin( publisher_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Publisher_Sanitize::color( publisher_get_settings( 'navigation_ad_background' ) );

	$css['global']['.searchbox-icon svg']['fill'] = Publisher_Sanitize::color( publisher_get_settings( 'header_search_icon_color' ) );
	// focus border color.
	$searchbox_input = [
		'#site-header .header-search .searchbox.searchbox-open .searchbox-input:focus',
		'#site-header .header-search .searchbox.searchbox-open .searchbox-input:hover',
	];
	// border color.
	$css['global'][ publisher_implode( $searchbox_input ) ]['border-color'] = Publisher_Sanitize::color( publisher_get_settings( 'header_search_icon_color' ) );

	// Layout 2 Header Nav Sections.
	$header_layout_nav_class = [
		'.header-layout2-bottom',
	];
	publisher_merge_value( $css['global'][ publisher_implode( $header_layout_nav_class ) ], Publisher_Sanitize::background( publisher_get_settings( 'header_layout2_nav_background' ) ) );
	publisher_merge_value( $css['global'][ publisher_implode( $header_layout_nav_class ) ], Publisher_Sanitize::padding( publisher_get_settings( 'header_layout2_nav_padding' ) ) );
	publisher_merge_value( $css['global'][ publisher_implode( $header_layout_nav_class ) ], Publisher_Sanitize::margin( publisher_get_settings( 'header_layout2_nav_margin' ) ) );
	$header_layout2_nav_border = Publisher_Sanitize::border( publisher_get_settings( 'header_layout2_nav_border' ) );
	$css['global'][ publisher_implode( $header_layout_nav_class ) ][ $header_layout2_nav_border ['direction'] ] = $header_layout2_nav_border ['value'];

	// Floating Navigation Responsive.
	if ( ! publisher_get_settings( 'sticky_responsive_nav' ) ) :
		$css['@media screen and (max-width: 865px)']['#catcher']['height'] = '0px!important';
		// position relative!important.
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, .admin-bar .sticky-navigation-active']['top']  = '0px!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, #header.sticky-navigation-active']['position'] = 'relative!important';
	endif;

	if ( ! publisher_get_settings( 'header_search_box' ) ) :
		$header_search_box = [
			'#site-header .header-search + #primary-navigation',
			'#site-header .header-search + .header-social-icons',
		];
		$css['global'][ publisher_implode( $header_search_box ) ]['margin-right'] = '0px!important';
	endif;
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Publisher_Sanitize::background( publisher_get_settings( 'social_styling_background' ) );
	publisher_merge_value( $css['global']['.shareit.floating'], Publisher_Sanitize::margin( publisher_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Publisher_Sanitize::border( publisher_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = publisher_get_settings( 'social_button_layout' );
	$social_button_position = publisher_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */

function publisher_featured_area_post( &$css ) {
	if ( publisher_get_settings( 'show_featured_area' ) ) :
		$i         = 0;
		$tab_lists = publisher_get_settings( 'featured_tab_list' );
		if ( $tab_lists && is_array( $tab_lists ) ) {
			foreach ( $tab_lists as $list ) {
				$css['global'][ '.tabs-menu li .tab-' . $i . '.button' ]['color']            = Publisher_Sanitize::color( $list['category_tab_color'] );
				$css['global'][ '.tabs-menu li .tab-' . $i . '.button' ]['background']       = Publisher_Sanitize::color( $list['category_tab_bgcolor'] );
				$css['global'][ '.tabs-menu li .tab-' . $i . '.button:hover' ]['color']      = Publisher_Sanitize::color( $list['category_tab_hover_color'] );
				$css['global'][ '.tabs-menu li .tab-' . $i . '.button:hover' ]['background'] = Publisher_Sanitize::color( $list['category_tab_hover_bgcolor'] );
				$css['global'][ '.tabs-menu li .tab-' . $i . '.button' ]['border-radius']    = Publisher_Sanitize::size( $list['category_tab_border_radius'] . 'px' );
				// active tab.
				$css['global'][ '.tabs-menu li.active .tab-' . $i . '.button' ]['color']      = Publisher_Sanitize::color( $list['category_tab_hover_color'] );
				$css['global'][ '.tabs-menu li.active .tab-' . $i . '.button' ]['background'] = Publisher_Sanitize::color( $list['category_tab_hover_bgcolor'] );
				$i++;
			}
		}
		// Featured Area.
		$featured_area_section = '.featured-area-section';
		publisher_merge_value( $css['global'][ $featured_area_section ], Publisher_Sanitize::background( publisher_get_settings( 'featured_area_background' ) ) );
		publisher_merge_value( $css['global'][ $featured_area_section ], Publisher_Sanitize::margin( publisher_get_settings( 'featured_area_margin' ) ) );
		publisher_merge_value( $css['global'][ $featured_area_section ], Publisher_Sanitize::padding( publisher_get_settings( 'featured_area_padding' ) ) );

		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_heading_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_subheading_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_tab_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_post_title_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_post_excerpt_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_post_cats_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_post_author_font' ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_post_date_font' ) ) );
		// Border.
		$featured_area_border = Publisher_Sanitize::border( publisher_get_settings( 'featured_area_border' ) );
		$css['global'][ $featured_area_section ][ $featured_area_border ['direction'] ] = $featured_area_border ['value'];
		// Next / Previous Buttton.
		$featured_nav_button       = '.custom-nav a.button';
		$featured_nav_hover_button = '.custom-nav a.button:hover';
		$css['global'][ publisher_implode( $featured_nav_button ) ]['color']                  = Publisher_Sanitize::color( publisher_get_settings( 'custom_nav_color' ) );
		$css['global'][ publisher_implode( $featured_nav_button ) ]['background-color']       = Publisher_Sanitize::color( publisher_get_settings( 'custom_nav_bgcolor' ) );
		$css['global'][ publisher_implode( $featured_nav_hover_button ) ]['color']            = Publisher_Sanitize::color( publisher_get_settings( 'custom_nav_hover_color' ) );
		$css['global'][ publisher_implode( $featured_nav_hover_button ) ]['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'custom_nav_hover_bgcolor' ) );
		$featured_tab_post_radius = [
			'.featured-tab-content #featured-thumbnail img',
			'.featured-tab-content .wrapper',
		];
		$css['global'][ publisher_implode( $featured_tab_post_radius ) ]['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'featured_post_border_radius' ) . 'px' );

	endif;
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_sidebar_styling( &$css ) {

	// Sidebar.
	$sidebar_widget = '.sidebar .widget';
	publisher_merge_value( $css['global'][ $sidebar_widget ], Publisher_Sanitize::background( publisher_get_settings( 'sidebar_styling_background' ) ) );
	publisher_merge_value( $css['global'][ $sidebar_widget ], Publisher_Sanitize::margin( publisher_get_settings( 'sidebar_styling_margin' ) ) );
	publisher_merge_value( $css['global'][ $sidebar_widget ], Publisher_Sanitize::padding( publisher_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Publisher_Sanitize::border( publisher_get_settings( 'sidebar_styling_border' ) );
	$css['global'][ $sidebar_widget ][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Publisher_Sanitize::background( publisher_get_settings( 'sidebar_title_styling_background' ) );
	publisher_merge_value( $css['global'][ $sidebar_title ], Publisher_Sanitize::padding( publisher_get_settings( 'sidebar_title_styling_padding' ) ) );
	publisher_merge_value( $css['global'][ $sidebar_title ], Publisher_Sanitize::margin( publisher_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Publisher_Sanitize::border( publisher_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

	// Subscribe Box.
	$css['global']['.widget.wp_subscribe'] = Publisher_Sanitize::background( publisher_get_settings( 'subscribe_widget_background' ) );
	publisher_merge_value( $css['global']['.widget.wp_subscribe'], Publisher_Sanitize::padding( publisher_get_settings( 'subscribe_widget_padding' ) ) );
	$subscribe_border = Publisher_Sanitize::border( publisher_get_settings( 'subscribe_widget_border' ) );
	$css['global']['.widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['.widget #wp-subscribe input.submit']['background'] = Publisher_Sanitize::color( publisher_get_settings( 'subscribe_widget_submit_backgroud' ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_post_layouts( &$css ) {

	// Post Layouts.
	$features = publisher_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id;
		publisher_merge_value( $css['global'][ $title_class ], Publisher_Sanitize::margin( publisher_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		publisher_merge_value( $css['global'][ $title_class ], Publisher_Sanitize::padding( publisher_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Publisher_Sanitize::border( publisher_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Publisher_Sanitize::border( publisher_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];
		/**
		 * Meta info
		 */
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'mts_cats_meta_info_font_' . $unique_id ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'mts_author_meta_info_font_' . $unique_id ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'mts_date_meta_info_font_' . $unique_id ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'post_title_font_' . $unique_id ) ) );
		publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		$css['global'][ $post_class ] = Publisher_Sanitize::background( publisher_get_settings( 'post_background_' . $unique_id ) );
		// All Posts Margin and Padding.
		publisher_merge_value( $css['global'][ $post_class ], Publisher_Sanitize::margin( publisher_get_settings( 'post_margin_' . $unique_id ) ) );
		publisher_merge_value( $css['global'][ $post_class ], Publisher_Sanitize::padding( publisher_get_settings( 'post_padding_' . $unique_id ) ) );

		// Post Alignment.
		$post_alignment       = publisher_get_settings( 'post_alignment_' . $unique_id );
		$post_alignment_class = [
			'.layout-' . $unique_id . ' .latestPost',
		];
		if ( 'center' === $post_alignment ) :
			$css['global'][ publisher_implode( $post_alignment_class ) ]['text-align'] = 'center';
		endif;
		if ( 'right' === $post_alignment ) :
			$css['global'][ publisher_implode( $post_alignment_class ) ]['text-align'] = 'right';
		endif;

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = [
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'.single .pagination > .current .currenttext',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	];
	$pagination_class        = [
		'.pagination a',
		'#load-posts a',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	];
	if ( '2' !== publisher_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ publisher_implode( $pagination_class ) ]['background-color']        = Publisher_Sanitize::color( publisher_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ publisher_implode( $pagination_class ) ]['color']                   = Publisher_Sanitize::color( publisher_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['color']            = Publisher_Sanitize::color( publisher_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['border-color']     = Publisher_Sanitize::color( publisher_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		publisher_merge_value( $css['global'][ publisher_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Publisher_Sanitize::margin( publisher_get_settings( 'mts_pagenavigation_margin' ) ) );
		publisher_merge_value( $css['global'][ publisher_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Publisher_Sanitize::padding( publisher_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ publisher_implode( $pagination_class ) ]['min-width']          = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['min-width']   = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ publisher_implode( $pagination_class ) ]['line-height']        = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['line-height'] = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Publisher_Sanitize::border( publisher_get_settings( 'pagenavigation_border' ) );
		$css['global'][ publisher_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Publisher_Sanitize::border( publisher_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ publisher_implode( $pagination_class ) ]['border-radius']                                 = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['border-radius']                          = Publisher_Sanitize::size( publisher_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ publisher_implode( $pagination_class ) ]['background-color']        = Publisher_Sanitize::color( publisher_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ publisher_implode( $pagination_class ) ]['color']                   = Publisher_Sanitize::color( publisher_get_settings( 'load_more_color' ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['color']            = Publisher_Sanitize::color( publisher_get_settings( 'load_more_hover_color' ) );
		publisher_merge_value( $css['global'][ publisher_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Publisher_Sanitize::padding( publisher_get_settings( 'load_more_padding' ) ) );
		publisher_merge_value( $css['global'][ publisher_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Publisher_Sanitize::margin( publisher_get_settings( 'load_more_margin' ) ) );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['border-color'] = Publisher_Sanitize::color( publisher_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Publisher_Sanitize::border( publisher_get_settings( 'load_more_border' ) );
		$css['global'][ publisher_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ publisher_implode( $pagination_class ) ]['border-radius']                   = Publisher_Sanitize::size( publisher_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ publisher_implode( $pagination_class_active ) ]['border-radius']            = Publisher_Sanitize::size( publisher_get_settings( 'load_more_border_radius' ) . 'px' );
	}

	// Load more Alignment.
	$load_more_align = publisher_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = [
		'.single_post',
		'.page .article',
		'.error404 .article',
	];

	$css['global'][ publisher_implode( $page_classes ) ] = Publisher_Sanitize::background( publisher_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	publisher_merge_value( $css['global'][ publisher_implode( $page_classes ) ], Publisher_Sanitize::margin( publisher_get_settings( 'mts_single_styling_margin' ) ) );
	publisher_merge_value( $css['global'][ publisher_implode( $page_classes ) ], Publisher_Sanitize::padding( publisher_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Publisher_Sanitize::border( publisher_get_settings( 'single_styling_border' ) );
	$css['global'][ publisher_implode( $page_classes ) ][ $single_border ['direction'] ] = $single_border ['value'];

	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_meta_cats_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_meta_author_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'single_meta_date_font' ) ) );

	// Breadcrumb.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'breadcrumb_font' ) ) );
	$breadcrumb_class = [
		'.breadcrumb-wrapper',
	];

	$css['global'][ publisher_implode( $breadcrumb_class ) ] = Publisher_Sanitize::background( publisher_get_settings( 'breadcrumb_background' ) );
	publisher_merge_value( $css['global'][ publisher_implode( $breadcrumb_class ) ], Publisher_Sanitize::margin( publisher_get_settings( 'breadcrumb_margin' ) ) );
	publisher_merge_value( $css['global'][ publisher_implode( $breadcrumb_class ) ], Publisher_Sanitize::padding( publisher_get_settings( 'breadcrumb_padding' ) ) );

	$breadcrumb_border = Publisher_Sanitize::border( publisher_get_settings( 'breadcrumb_border' ) );
	$css['global'][ publisher_implode( $breadcrumb_class ) ][ $breadcrumb_border ['direction'] ] = $breadcrumb_border ['value'];
	$breadcrumb_class = [
		'.breadcrumb .separator',
	];
	$breadcrumb_font  = publisher_get_settings( 'breadcrumb_font' );
	$css['global'][ publisher_implode( $breadcrumb_class ) ]['background-color'] = Publisher_Sanitize::color( $breadcrumb_font['color'] );

	// Tags.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'tags_font' ) ) );
	$css['global']['.tags a']['background-color']       = Publisher_Sanitize::color( publisher_get_settings( 'tags_bgcolor' ) );
	$css['global']['.tags a:hover']['color']            = Publisher_Sanitize::color( publisher_get_settings( 'tags_hover_color' ) );
	$css['global']['.tags a:hover']['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'tags_hover_bgcolor' ) );
	$css['global']['.tags a']['border-radius']          = Publisher_Sanitize::size( publisher_get_settings( 'tags_border_radius' ) . 'px' );

	$css['global']['.tags'] = Publisher_Sanitize::background( publisher_get_settings( 'tags_background' ) );
	publisher_merge_value( $css['global']['.tags'], Publisher_Sanitize::margin( publisher_get_settings( 'tags_margin' ) ) );
	publisher_merge_value( $css['global']['.tags'], Publisher_Sanitize::padding( publisher_get_settings( 'tags_padding' ) ) );

	// Related Posts.
	$related_class = [
		'.related-posts',
	];
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'related_meta_cats_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'related_meta_author_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'related_meta_date_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'related_posts_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'related_posts_text_font' ) ) );
	$css['global'][ publisher_implode( $related_class ) ] = Publisher_Sanitize::background( publisher_get_settings( 'related_posts_background' ) );
	publisher_merge_value( $css['global'][ publisher_implode( $related_class ) ], Publisher_Sanitize::margin( publisher_get_settings( 'related_posts_margin' ) ) );
	publisher_merge_value( $css['global'][ publisher_implode( $related_class ) ], Publisher_Sanitize::padding( publisher_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Publisher_Sanitize::border( publisher_get_settings( 'related_posts_border' ) );
	$css['global'][ publisher_implode( $related_class ) ][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts .latestPost'] = Publisher_Sanitize::background( publisher_get_settings( 'related_article_background' ) );
	publisher_merge_value( $css['global']['.related-posts .latestPost'], Publisher_Sanitize::padding( publisher_get_settings( 'related_article_padding' ) ) );

	// Post FullHeader.
	publisher_merge_value( $css['global']['.single-full-header-content'], Publisher_Sanitize::padding( publisher_get_settings( 'featured_image_padding' ) ) );
	publisher_merge_value( $css['global']['.single-full-header'], Publisher_Sanitize::margin( publisher_get_settings( 'featured_image_margin' ) ) );
	$css['global']['.single-full-header-content']['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'featured_image_opacity' ) );
	// Subscribe Box Input border.
	$single_meta_info_top_border = Publisher_Sanitize::border( publisher_get_settings( 'single_meta_info_top_border' ) );
	$css['global']['.single-full-header .post-info-bottom'][ $single_meta_info_top_border ['direction'] ] = $single_meta_info_top_border ['value'];

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Publisher_Sanitize::background( publisher_get_settings( 'single_subscribe_background' ) );
	publisher_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Publisher_Sanitize::margin( publisher_get_settings( 'single_subscribe_margin' ) ) );
	publisher_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Publisher_Sanitize::padding( publisher_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Publisher_Sanitize::border( publisher_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = [
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	];
	$css['global'][ publisher_implode( $subscribe_input_class ) ]['height'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['line-height'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ publisher_implode( $subscribe_input_class ) ]['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Publisher_Sanitize::border( publisher_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ publisher_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Publisher_Sanitize::color( publisher_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Publisher_Sanitize::border( publisher_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	publisher_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Publisher_Sanitize::padding( publisher_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Publisher_Sanitize::background( publisher_get_settings( 'authorbox_background' ) );
	publisher_merge_value( $css['global']['.postauthor'], Publisher_Sanitize::margin( publisher_get_settings( 'authorbox_margin' ) ) );
	publisher_merge_value( $css['global']['.postauthor'], Publisher_Sanitize::padding( publisher_get_settings( 'authorbox_padding' ) ) );
	$css['global']['.postauthor']['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'authorbox_border_radius' ) . 'px' );
	// Border.
	$authorbox_border = Publisher_Sanitize::border( publisher_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];
	// Author image.
	publisher_merge_value( $css['global']['.postauthor img'], Publisher_Sanitize::margin( publisher_get_settings( 'single_author_image_margin' ) ) );
	$css['global']['.postauthor img']['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'single_author_image_border_radius' ) . 'px' );
	// Author Social.
	publisher_merge_value( $css['global']['.author-social a'], Publisher_Sanitize::margin( publisher_get_settings( 'author_social_margin' ) ) );
	publisher_merge_value( $css['global']['.author-social a'], Publisher_Sanitize::padding( publisher_get_settings( 'author_social_padding' ) ) );
	$css['global']['.author-social a'] ['background']       = Publisher_Sanitize::color( publisher_get_settings( 'author_social_background' ) );
	$css['global']['.author-social a:hover'] ['background'] = Publisher_Sanitize::color( publisher_get_settings( 'author_social_hover_background' ) );
	$css['global']['.author-social a']['color']             = Publisher_Sanitize::color( publisher_get_settings( 'author_social_color' ) );
	$css['global']['.author-social a:hover']['color']       = Publisher_Sanitize::color( publisher_get_settings( 'author_social_hover_color' ) );
	$css['global']['.author-social a']['border-radius']     = Publisher_Sanitize::size( publisher_get_settings( 'author_social_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = publisher_get_settings( 'single_title_alignment' );

	$titles_align_class = [
		'.comment-title',
		'#respond',
		'.related-posts-title',
	];
	$titles_class       = [
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	];

	$css['global'][ publisher_implode( $titles_class ) ] = Publisher_Sanitize::background( publisher_get_settings( 'single_title_background' ) );
	publisher_merge_value( $css['global'][ publisher_implode( $titles_class ) ], Publisher_Sanitize::padding( publisher_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Publisher_Sanitize::border( publisher_get_settings( 'single_title_border' ) );
	$css['global'][ publisher_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ publisher_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ publisher_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ publisher_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ publisher_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ publisher_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.

	// Author Comment.
	$css['global']['#comments li.bypostauthor .comment-list']['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'author_comment_bg' ) );

	// Typography.
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'comments_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'comments_meta_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'comments_text_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'reply_font' ) ) );

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_copyrights( &$css ) {

	// Copyrights.
	publisher_merge_value( $css['global']['.copyrights'], Publisher_Sanitize::margin( publisher_get_settings( 'mts_copyrights_margin' ) ) );
	publisher_merge_value( $css['global']['.copyrights'], Publisher_Sanitize::padding( publisher_get_settings( 'mts_copyrights_padding' ) ) );
	publisher_merge_value( $css['global']['..copyrights'], Publisher_Sanitize::background( publisher_get_settings( 'mts_copyrights_background' ) ) );
	$copyrights_border = Publisher_Sanitize::border( publisher_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_footer( &$css ) {

	// Footer.
	publisher_merge_value( $css['global']['#site-footer'], Publisher_Sanitize::margin( publisher_get_settings( 'mts_top_footer_margin' ) ) );
	publisher_merge_value( $css['global']['#site-footer .footer-widgets'], Publisher_Sanitize::padding( publisher_get_settings( 'mts_top_footer_padding' ) ) );
	$mts_top_footer_border = Publisher_Sanitize::border( publisher_get_settings( 'mts_top_footer_border' ) );
	$css['global']['#site-footer'][ $mts_top_footer_border ['direction'] ] = $mts_top_footer_border ['value'];

	// Subscribe Box.
	$css['global']['#site-footer .widget.wp_subscribe'] = Publisher_Sanitize::background( publisher_get_settings( 'footer_subscribe_widget_background' ) );
	publisher_merge_value( $css['global']['#site-footer .widget.wp_subscribe'], Publisher_Sanitize::padding( publisher_get_settings( 'footer_subscribe_widget_padding' ) ) );
	$footer_subscribe_border = Publisher_Sanitize::border( publisher_get_settings( 'footer_subscribe_widget_border' ) );
	$css['global']['#site-footer .widget.wp_subscribe'][ $footer_subscribe_border ['direction'] ] = $footer_subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['#site-footer .widget #wp-subscribe input.submit']['background'] = Publisher_Sanitize::color( publisher_get_settings( 'footer_subscribe_widget_submit_backgroud' ) );

	// Footer title.
	$footer_title                   = '#site-footer .widget h3';
	$css['global'][ $footer_title ] = Publisher_Sanitize::background( publisher_get_settings( 'footer_title_styling_background' ) );
	publisher_merge_value( $css['global'][ $footer_title ], Publisher_Sanitize::padding( publisher_get_settings( 'footer_title_styling_padding' ) ) );
	publisher_merge_value( $css['global'][ $footer_title ], Publisher_Sanitize::margin( publisher_get_settings( 'footer_title_styling_margin' ) ) );

	// Footer Title border.
	$footer_title_border = Publisher_Sanitize::border( publisher_get_settings( 'footer_widget_title_border' ) );
	$css['global'][ $footer_title ][ $footer_title_border['direction'] ] = $footer_title_border['value'];

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_archive_post( &$css ) {

	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'archive_post_title_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'archive_post_excerpt_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'archive_meta_cats_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'archive_meta_author_font' ) ) );
	publisher_map_css_selectors( $css['global'], Publisher_Sanitize::typography( publisher_get_settings( 'archive_meta_date_font' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function publisher_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Publisher_Sanitize::padding( publisher_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Show Logo.
	$show_logo = publisher_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	$css['global']['#move-to-top']['background-color']       = Publisher_Sanitize::color( publisher_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background-color'] = Publisher_Sanitize::color( publisher_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Publisher_Sanitize::border( publisher_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	publisher_merge_value( $css['global']['#move-to-top'], Publisher_Sanitize::padding( publisher_get_settings( 'top_button_padding' ) ) );
	if ( 'floating' === publisher_get_settings( 'bt_top_button_position' ) ) :
		$top_button_position = publisher_get_settings( 'top_button_position' );
		foreach ( $top_button_position as $key => $position ) {
			$css['global']['#move-to-top'][ $key ] = $position;
		}
	endif;
	if ( 'bottom' === publisher_get_settings( 'bt_top_button_position' ) ) :
		$top_bottom_button_position = publisher_get_settings( 'top_bottom_button_margin' );
		foreach ( $top_bottom_button_position as $key => $position ) {
			$css['global']['.move-to-top'][ $key ] = $position;
		}
	endif;
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Publisher_Sanitize::size( publisher_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top svg path']['stroke']       = Publisher_Sanitize::color( publisher_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover svg path']['stroke'] = Publisher_Sanitize::color( publisher_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top:hover']['border-color']    = Publisher_Sanitize::color( publisher_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === publisher_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

}
